💾 Installation - ngff-zarr
Description: System Browser In Pyodide, e.g. the Pyodide REPL or JupyterLite, Optional dependencies include: cli: Additional IO libraries for the command line interface (CLI). dask-image: Multiscale generation ...

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Edit this page
Toggle table of contents sidebar

# 💾 Installation

System

    pip install "ngff-zarr[cli]"

Browser In Pyodide, e.g. the

Pyodide REPL or JupyterLite,

    import micropip
    await micropip.install('ngff-zarr')

Optional dependencies include:

`cli` : Additional IO libraries for the command line interface (CLI).

`dask-image` : Multiscale generation with `dask-image` methods.

`itk` : Multiscale generation with `itk` methods.